<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    // Check if 'subjectid' and 'userid' are provided in the query parameters
    if (!isset($_GET['subjectid']) || empty($_GET['subjectid']) || 
        !isset($_GET['userid']) || empty($_GET['userid'])) {
        http_response_code(400); // Bad Request
        echo json_encode(['message' => 'Subject ID and User ID parameters are required']);
        exit;
    }

    $subjectId = $_GET['subjectid'];
    $userid = $_GET['userid'];
    $baseUrl = 'https://optima-software-solutions.com/falcon/dasboard/uploads/chapters/'; // Base URL for images

    try {
        // Check if the student is enrolled in the subject
        $stmt = $con->prepare('SELECT id FROM studentssubjects WHERE studentid = ? AND subjectid = ?');
        $stmt->execute([$userid, $subjectId]);
        if (!$stmt->fetch(PDO::FETCH_ASSOC)) {
            http_response_code(403); // Forbidden
            echo json_encode(['message' => 'Student is not enrolled in this subject']);
            exit;
        }

        // Fetch all chapters associated with the subject ID
        $stmt = $con->prepare('SELECT id, name, course, subjectid, image, description FROM week_chapters WHERE subjectid = ?');
        $stmt->execute([$subjectId]);
        $chapters = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Add image URL and handle null images
        foreach ($chapters as &$chapter) {
            // Cast id and subjectid to string
            $chapter['id'] = (string) $chapter['id'];
            $chapter['subjectid'] = (string) $chapter['subjectid'];
            if (!empty($chapter['image'])) {
                $chapter['image_url'] = $baseUrl . $chapter['image']; // Construct the full URL for the image
            } else {
                $chapter['image_url'] = 'No image found'; // Placeholder if no image is available
            }
            unset($chapter['image']); // Optionally remove the original image field
        }

        // Prepare the response with success message
        $response = [
            'message' => 'success',
            'chapters' => $chapters
        ];

    } catch (Exception $e) {
        // In case of an error, return a failure message
        $response = [
            'message' => 'failure',
            'error' => $e->getMessage()
        ];
        http_response_code(500); // Internal Server Error
    }

    echo json_encode($response);

} else {
    // Invalid request method, return an error response
    http_response_code(405); // Method Not Allowed
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>
