<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get the input data from the body
    $data = json_decode(file_get_contents('php://input'), true);

    // Validate input
    if (empty($data['studentid']) || empty($data['videoid'])) {
        http_response_code(400); // Bad Request
        echo json_encode(['message' => 'studentid and videoid are required']);
        exit;
    }

    $studentId = $data['studentid'];
    $videoId = $data['videoid'];

    try {
        // Get the maximum view count for the video from the videos table
        $stmt = $con->prepare('SELECT no FROM videos WHERE id = ?');
        $stmt->execute([$videoId]);
        $video = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$video) {
            http_response_code(404); // Not Found
            echo json_encode(['message' => 'Video not found']);
            exit;
        }

        $maxViews = $video['no'];

        // Check if the student has already viewed the video and get the current timer count
        $stmt = $con->prepare('SELECT id, timer FROM videocount WHERE studentid = ? AND videoid = ?');
        $stmt->execute([$studentId, $videoId]);
        $view = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($view) {
            // If the student has viewed the video, increase the timer
            $newTimer = $view['timer'] + 1;

            // Check if the new timer value exceeds the maximum allowed views
            if ($newTimer >= $maxViews) {
                echo json_encode(['message' => 'Reached maximum limit', 'view_count' => $newTimer]);
                exit;
            }

            // Update the timer in the database
            $stmt = $con->prepare('UPDATE videocount SET timer = ? WHERE id = ?');
            $stmt->execute([$newTimer, $view['id']]);
        } else {
            // If this is the first view, insert a new record with a timer value of 1
            $stmt = $con->prepare('INSERT INTO videocount (studentid, videoid, timer) VALUES (?, ?, 1)');
            $stmt->execute([$studentId, $videoId]);
            $newTimer = 1;
        }

        // Prepare and return the success response with the current timer value
        $response = [
            'id' => $videoId,
            'view_count' => $newTimer
        ];
        echo json_encode($response);

    } catch (Exception $e) {
        // Handle any errors
        http_response_code(500); // Internal Server Error
        echo json_encode(['message' => 'Error counting view', 'error' => $e->getMessage()]);
    }

} else {
    // Invalid request method
    http_response_code(405);
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>
