<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get the input data
    $data = json_decode(file_get_contents('php://input'), true);

    // Validate input
    if (empty($data['id'])) {
        http_response_code(400); // Bad Request
        echo json_encode(['message' => 'Student ID is required']);
        exit;
    }

    // Check if the student exists by ID
    $stmt = $con->prepare('SELECT * FROM students WHERE id = ?');
    $stmt->execute([$data['id']]);
    $student = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$student) {
        http_response_code(404); // Not Found
        echo json_encode(['message' => 'Student not found']);
        exit;
    }

    // Prepare the update query
    $updateFields = [];
    $params = [];
    
    // Update fields only if new values are provided
    if (!empty($data['name'])) {
        $updateFields[] = 'username = ?';
        $params[] = $data['name'];
    }
    if (!empty($data['phone'])) {
        $updateFields[] = 'phone = ?';
        $params[] = $data['phone'];
    }
    if (!empty($data['password'])) {
        // Hash the new password
        $updateFields[] = 'password = ?';
        $params[] = password_hash($data['password'], PASSWORD_BCRYPT);
    }
    if (!empty($data['email'])) {
        $updateFields[] = 'email = ?';
        $params[] = $data['email'];
    }
    if (!empty($data['univercity'])) {
        $updateFields[] = 'university = ?';
        $params[] = $data['univercity'];
    }
    if (!empty($data['faculty'])) {
        $updateFields[] = 'faculty = ?';
        $params[] = $data['faculty'];
    }
    if (!empty($data['level'])) {
        $updateFields[] = 'eductionallevel = ?';
        $params[] = $data['level'];
    }

    // Check if there are fields to update
    if (empty($updateFields)) {
        http_response_code(400); // Bad Request
        echo json_encode(['message' => 'No fields to update']);
        exit;
    }

    // Add the student ID to parameters
    $params[] = $data['id'];

    // Prepare and execute the update query
    $sql = 'UPDATE students SET ' . implode(', ', $updateFields) . ' WHERE id = ?';
    try {
        $stmt = $con->prepare($sql);
        $stmt->execute($params);

        // Fetch the updated student details
        $stmt = $con->prepare('SELECT s.id, s.username AS name, s.phone, s.email, s.university, s.faculty, s.eductionallevel AS level, s.fcmtoken
            FROM students s
            WHERE s.id = ?');
        $stmt->execute([$data['id']]);
        $updatedStudent = $stmt->fetch(PDO::FETCH_ASSOC);

        // Prepare success response with the updated student object
        $response = [
            'message' => 'Student details updated successfully',
            'student' => $updatedStudent
        ];
        echo json_encode($response);

    } catch (Exception $e) {
        // In case of an error
        http_response_code(500); // Internal Server Error
        echo json_encode(['message' => 'Failed to update student details', 'error' => $e->getMessage()]);
    }
} else {
    // Invalid request method
    http_response_code(405); // Method Not Allowed
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>
