<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get the input data
    $data = json_decode(file_get_contents('php://input'), true);

    // Validate input
    if (empty($data['studentid']) || empty($data['quizid']) || empty($data['answers'])) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'Missing required fields']);
        exit;
    }

    $studentId = $data['studentid'];
    $quizId = $data['quizid'];
    $answers = $data['answers'];

    try {
        // Begin a transaction
        $con->beginTransaction();

        $totalDegree = 0; // Initialize total degree

        foreach ($answers as $answer) {
            $questionId = $answer['questionid'];
            $choice = $answer['choice']; // This will be 1, 2, 3, or 4

            // Fetch the degree for the question
            $stmt = $con->prepare('SELECT degree FROM examquestions WHERE examid = ? AND questionid = ?');
            $stmt->execute([$quizId, $questionId]);
            $exam = $stmt->fetch(PDO::FETCH_ASSOC);

            if ($exam === false) {
                throw new Exception('Exam not found');
            }

            $degree = $exam['degree'];

            // Fetch the correct answer choices from the questions table
            $stmt = $con->prepare('SELECT answer FROM questions WHERE id = ?');
            $stmt->execute([$questionId]);
            $question = $stmt->fetch(PDO::FETCH_ASSOC);

            if ($question === false) {
                throw new Exception('Question not found');
            }

            // Check if the selected choice is correct
            $correctAnswer = $question['answer']; // This should correspond to the choice (1-4)
            if ($choice == $correctAnswer) {
                // Accumulate total degree only if the answer is correct
                $totalDegree += $degree;
            }

            // Insert the answer into the examsanswer table
            $stmt = $con->prepare('INSERT INTO examsanswer (studentid, questionid, examid, answer, degree) VALUES (?, ?, ?, ?, ?)');
            $stmt->execute([$studentId, $questionId, $quizId, $choice, $degree]);
        }

        // Insert into studentexam table
        $endTime = date('Y-m-d H:i:s'); // Get current timestamp
        $stmt = $con->prepare('INSERT INTO studentexam (studentid, examid, result, end_time) VALUES (?, ?, ?, ?)');
        $stmt->execute([$studentId, $quizId, $totalDegree, $endTime]);

        // Commit the transaction
        $con->commit();

        // Prepare success response
        $response = ['success' => 'Answers submitted successfully', 'totalDegree' => $totalDegree];
        echo json_encode($response);

    } catch (Exception $e) {
        // Rollback the transaction if there is an error
        $con->rollBack();
        
        // Prepare error response
        http_response_code(500); // Internal Server Error
        $response = ['error' => 'Failed to submit answers', 'details' => $e->getMessage()];
        echo json_encode($response);
    }

} else {
    // Invalid request method
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Method Not Allowed']);
}
?>