<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    $baseUrl = 'https://optima-software-solutions.com/falcon/dasboard/uploads/chapters/'; // Base URL for images

    try {
        // Fetch the last 5 chapters along with the subject names and image URLs
        $stmt = $con->query('SELECT wc.id, wc.name AS chapter_name, wc.course, s.name AS subject_name, wc.image, wc.description
            FROM week_chapters wc
            LEFT JOIN subjects s ON wc.subjectid = s.id
            ORDER BY wc.id DESC
            LIMIT 5
        ');
        $chaptersData = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Add image URL and handle null images
        foreach ($chaptersData as &$chapter) {
            // Cast id to string
            $chapter['id'] = (string) $chapter['id'];
            
            if (!empty($chapter['image'])) {
                $chapter['image_url'] = $baseUrl . $chapter['image']; // Construct the full URL for the image
            } else {
                $chapter['image_url'] = 'No image found'; // Placeholder if no image is available
            }
            unset($chapter['image']); // Optionally remove the original image field
        }

        // Prepare the response with success message
        $response = [
            'message' => 'success',
            'latest_chapters' => $chaptersData
        ];

    } catch (Exception $e) {
        // In case of an error, return a failure message
        $response = [
            'message' => 'failure',
            'error' => $e->getMessage()
        ];
        http_response_code(500); // Internal Server Error
    }

    echo json_encode($response);

} else {
    // Invalid request method, return an error response
    http_response_code(405); // Method Not Allowed
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>