<?php 
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get the input data
    $data = json_decode(file_get_contents('php://input'), true);

    // Validate input
    if (empty($data['email']) || empty($data['password']) || empty($data['deviceid'])) {
        http_response_code(400); // Bad Request
        echo json_encode(['message' => 'Email, password, and device ID are required']);
        exit;
    }

    // Check if email exists and get user details
    $stmt = $con->prepare('SELECT s.id, s.username AS name, s.phone, s.email, s.password, s.deviceid,
        u.name AS university_name, f.name AS college_name, l.name AS level_name
        FROM students s
        LEFT JOIN universities u ON s.university = u.id
        LEFT JOIN colleges f ON s.faculty = f.id
        LEFT JOIN levels l ON s.eductionallevel = l.id
        WHERE s.email = ?'
    );
    $stmt->execute([$data['email']]);
    $user = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$user) {
        http_response_code(401); // Unauthorized
        echo json_encode(['message' => 'Invalid email']);
        exit;
    }

    // Verify password
    if (!password_verify($data['password'], $user['password'])) {
        http_response_code(401); // Unauthorized
        echo json_encode(['message' => 'Invalid email or password']);
        exit;
    }

    // Check for specific user exception
    if ($data['email'] === 'testfalcon@gmail.com') {
        // No device ID check for this specific user
        // You may still want to update the device ID in the database
        $stmt = $con->prepare('UPDATE students SET deviceid = ? WHERE email = ?');
        $stmt->execute([$data['deviceid'], $data['email']]);
    } else {
        // Check if device ID matches or is null
        if ($user['deviceid'] && $user['deviceid'] !== $data['deviceid']) {
            http_response_code(401); // Unauthorized
            echo json_encode(['message' => 'This account is using another device']);
            exit;
        }
        
        // Update device ID
        $stmt = $con->prepare('UPDATE students SET deviceid = ? WHERE email = ?');
        $stmt->execute([$data['deviceid'], $data['email']]);
    }

    // Remove password from response
    unset($user['password']);

    // Cast the id to string
    $user['id'] = (string) $user['id'];

    // Prepare success response
    echo json_encode([
        'message' => 'Login successful',
        'user' => $user
    ]);

} else {
    // Invalid request method
    http_response_code(405);
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>
