<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    // Get the input parameters
    $studentId = isset($_GET['studentid']) ? $_GET['studentid'] : null;
    $quizId = isset($_GET['quizid']) ? $_GET['quizid'] : null;

    if (empty($studentId) || empty($quizId)) {
        http_response_code(400); // Bad Request
        echo json_encode(['message' => 'Student ID or Quiz ID parameter is missing']);
        exit;
    }

    try {
        // Fetch the student's answers from examsanswer table
        $stmt = $con->prepare('SELECT questionid, answer FROM examsanswer WHERE studentid = ? AND examid = ?');
        $stmt->execute([$studentId, $quizId]);
        $studentAnswers = $stmt->fetchAll(PDO::FETCH_ASSOC);

        if (empty($studentAnswers)) {
            http_response_code(404); // Not Found
            echo json_encode(['message' => 'No answers found for the given student and quiz']);
            exit;
        }

        // Fetch the correct answers, questions, and choices from the questions table
        $questionsIds = array_column($studentAnswers, 'questionid');
        $inQuery = implode(',', array_fill(0, count($questionsIds), '?'));

        $stmt = $con->prepare(
            "SELECT id, question, answer, choice1, choice2, choice3, choice4 
            FROM questions WHERE id IN ($inQuery)"
        );
        $stmt->execute($questionsIds);
        $questions = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Map the correct answers and choices by question ID
        $questionsMap = [];
        foreach ($questions as $question) {
            $correctAnswerText = '';
            switch ($question['answer']) {
                case 1:
                    $correctAnswerText = $question['choice1'];
                    break;
                case 2:
                    $correctAnswerText = $question['choice2'];
                    break;
                case 3:
                    $correctAnswerText = $question['choice3'];
                    break;
                case 4:
                    $correctAnswerText = $question['choice4'];
                    break;
            }

            $questionsMap[$question['id']] = [
                'question' => $question['question'],
                'correct_answer' => $correctAnswerText,
                'choices' => [
                    1 => $question['choice1'],
                    2 => $question['choice2'],
                    3 => $question['choice3'],
                    4 => $question['choice4'],
                ]
            ];
        }

        // Prepare the response with student answers and correct answers
        $response = [];
        foreach ($studentAnswers as $studentAnswer) {
            $questionId = $studentAnswer['questionid'];
            $studentChoiceIndex = intval($studentAnswer['answer']);

            // Fetch student's selected choice text
            $studentChoiceText = $questionsMap[$questionId]['choices'][$studentChoiceIndex] ?? 'Invalid answer';

            $response[] = [
                'question' => $questionsMap[$questionId]['question'],
                'student_answer' => $studentChoiceText,
                'correct_answer' => $questionsMap[$questionId]['correct_answer'],
            ];
        }

        echo json_encode(['answers' => $response]);

    } catch (Exception $e) {
        // In case of an error
        http_response_code(500); // Internal Server Error
        $response = ['message' => 'An error occurred', 'error' => $e->getMessage()];
        echo json_encode($response);
    }

} else {
    // Invalid request method
    http_response_code(405); // Method Not Allowed
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>