<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get the input data
    $data = json_decode(file_get_contents('php://input'), true);

    // Validate input
    if (empty($data['studentid']) || empty($data['subjectid']) || !isset($data['rate'])) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'Missing required fields']);
        exit;
    }

    $studentId = $data['studentid'];
    $subjectId = $data['subjectid'];
    $rate = $data['rate'];
    $comment = isset($data['comment']) ? $data['comment'] : null;

    try {
        // Insert the rating and optional comment into the database
        $stmt = $con->prepare('INSERT INTO students_rating (studentid, subjectid, rate, comment) VALUES (?, ?, ?, ?)');
        $stmt->execute([$studentId, $subjectId, $rate, $comment]);

        // Get the ID of the newly inserted rating
        $ratingId = $con->lastInsertId();

        // Fetch the student's username
        $stmt = $con->prepare('SELECT username FROM students WHERE id = ?');
        $stmt->execute([$studentId]);
        $student = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($student === false) {
            throw new Exception('Student not found');
        }
        $studentName = $student['username'];

        // Fetch the subject's name
        $stmt = $con->prepare('SELECT name FROM subjects WHERE id = ?');
        $stmt->execute([$subjectId]);
        $subject = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($subject === false) {
            throw new Exception('Subject not found');
        }
        $subjectName = $subject['name'];

        // Prepare the response object
        $response = [
            'id' => $ratingId,
            'student' => [
                'id' => $studentId,
                'name' => $studentName
            ],
            'subject' => [
                'id' => $subjectId,
                'name' => $subjectName
            ],
            'rating' => [
                'rate' => $rate,
                'comment' => $comment
            ]
        ];

        // Return success response with the detailed object
        echo json_encode($response);

    } catch (Exception $e) {
        // In case of an error
        http_response_code(500); // Internal Server Error
        $response = ['error' => 'Failed to add rating and comment', 'details' => $e->getMessage()];
        echo json_encode($response);
    }

} else {
    // Invalid request method
    http_response_code(405); // Method Not Allowed
    echo json_encode(['error' => 'Method Not Allowed']);
}
?>
