<?php
require_once 'connect.php'; // Include the database connection

// Enable error reporting for debugging
error_reporting(E_ALL);
ini_set('display_errors', 1);

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get the input data
    $data = json_decode(file_get_contents('php://input'), true);

    // Validate input
    if (empty($data['name']) || empty($data['phone']) || empty($data['email']) || empty($data['password']) || empty($data['university']) || empty($data['faculty']) || empty($data['level']) || empty($data['fcmtoken'])) {
        http_response_code(400); // Bad Request
        echo json_encode(['message' => 'All fields are required']);
        exit;
    }

    // Check if email already exists
    $stmt = $con->prepare('SELECT id FROM students WHERE email = ?');
    $stmt->execute([$data['email']]);
    if ($stmt->fetch(PDO::FETCH_ASSOC)) {
        http_response_code(400); // Bad Request
        echo json_encode(['message' => 'Email already exists']);
        exit;
    }

    // Hash the password
    $hashedPassword = password_hash($data['password'], PASSWORD_BCRYPT);

    // Insert user data into the database
    try {
        $stmt = $con->prepare('INSERT INTO students (username, email, password, phone, eductionallevel, university, faculty, fcmtoken)
            VALUES (?, ?, ?, ?, ?, ?, ?, ?)');
        $stmt->execute([
            $data['name'],
            $data['email'],
            $hashedPassword,
            $data['phone'],
            $data['level'],
            $data['university'],
            $data['faculty'],
            $data['fcmtoken']
        ]);

        // Get the last inserted ID
        $lastId = $con->lastInsertId();

        // Fetch the inserted row
        $stmt = $con->prepare('SELECT s.id, s.username AS name, s.phone, s.email, u.name AS university, f.name AS faculty, l.name AS level, s.fcmtoken
            FROM students s
            JOIN universities u ON s.university = u.id
            JOIN colleges f ON s.faculty = f.id
            JOIN levels l ON s.eductionallevel = l.id
            WHERE s.id = ?');
        $stmt->execute([$lastId]);
        $user = $stmt->fetch(PDO::FETCH_ASSOC);

        // Check if user data was fetched successfully
        if ($user) {
            // Prepare success response with the inserted user object
            $response = [
                'message' => 'Registration successful',
                'user' => $user
            ];
            echo json_encode($response);
        } else {
            // If no data is returned, something went wrong
            http_response_code(500); // Internal Server Error
            echo json_encode(['message' => 'User data not found']);
        }

    } catch (Exception $e) {
        // In case of an error
        http_response_code(500); // Internal Server Error
        $response = ['message' => 'Registration failed', 'error' => $e->getMessage()];
        echo json_encode($response);
    }
} else {
    // Invalid request method
    http_response_code(405);
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>
