<?php
// Enable error reporting for debugging
// ini_set('display_errors', 1);
// ini_set('display_startup_errors', 1);
// error_reporting(E_ALL);

require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

// Get the studentid from the URL parameter
if (!isset($_GET['studentid'])) {
    echo json_encode(["message" => "Student ID is required."]);
    exit();
}

$studentid = $_GET['studentid'];

try {
    // Check if the student ID exists in the students table
    $checkStudentQuery = "SELECT COUNT(*) FROM students WHERE id = :studentid";
    $stmt = $con->prepare($checkStudentQuery);
    $stmt->bindParam(":studentid", $studentid);
    $stmt->execute();
    $exists = $stmt->fetchColumn();

    // If the student ID does not exist, return a message
    if ($exists == 0) {
        echo json_encode(["message" => "Student ID not found."]);
        exit();
    }

    // Start a transaction
    $con->beginTransaction();

    // List of tables to delete from
    $tables = [
        "video_request", "examsanswer", "std_noti", "students_rating", "student_wallet", 
        "new_homework_answers", "quizstudent", "codes", "video_old_requests", "studenthw", 
        "videoquestions", "studentexam", "answers", "new_student_homework", 
        "report_screenshot", "studentssubjects", "videocount", "attendance",
        "modules_students"  // Add this table with a different column name
    ];

    // Initialize an array to store results
    $results = [];

    // Loop through each table and delete related records
    foreach ($tables as $table) {
        if ($table == "modules_students") {
            // Special case for "modules_students" where the column is "student_id"
            $deleteQuery = "DELETE FROM $table WHERE student_id = :studentid";
        } else {
            // General case for other tables where the column is "studentid"
            $deleteQuery = "DELETE FROM $table WHERE studentid = :studentid";
        }

        $stmt = $con->prepare($deleteQuery);
        $stmt->bindParam(":studentid", $studentid);
        $stmt->execute();

        // Store the number of affected rows
        $rowCount = $stmt->rowCount();
        $results[] = [
            "table" => $table,
            "deleted_rows" => $rowCount,
            "status" => $rowCount > 0 ? "Deleted" : "No records found"
        ];
    }

    // Delete from the students table where the column is "id"
    $deleteStudentQuery = "DELETE FROM students WHERE id = :studentid";
    $stmt = $con->prepare($deleteStudentQuery);
    $stmt->bindParam(":studentid", $studentid);
    $stmt->execute();

    // Store the result for students table
    $rowCount = $stmt->rowCount();

    // Commit the transaction
    $con->commit();

    // Return the results as JSON
    echo json_encode([
        "message" => "Account Deleted successfully.",
    ]);

} catch (Exception $e) {
    // Rollback the transaction if anything goes wrong
    $con->rollBack();
    echo json_encode(["message" => "Error deleting student: " . $e->getMessage()]);
}

?>
