<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get the input data
    $data = json_decode(file_get_contents('php://input'), true);

    // Validate input
    if (empty($data['studentid'])) {
        http_response_code(400); // Bad Request
        echo json_encode(['message' => 'Student ID is required']);
        exit;
    }

    // Get the student ID from the request
    $studentId = intval($data['studentid']);

    try {
        // Insert the record into the report_screenshot table
        $stmt = $con->prepare('INSERT INTO report_screenshot (studentid, status)
            VALUES (?, ?) ');
        $stmt->execute([$studentId, 1]);

        // Prepare success response
        $response = ['message' => 'Screenshot record inserted successfully'];
        echo json_encode($response);

    } catch (Exception $e) {
        // In case of an error
        http_response_code(500); // Internal Server Error
        $response = ['message' => 'Failed to insert record', 'error' => $e->getMessage()];
        echo json_encode($response);
    }
} else {
    // Invalid request method
    http_response_code(405); // Method Not Allowed
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>
