<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get input data
    $data = json_decode(file_get_contents('php://input'), true);

    // Validate input
    $type = isset($data['type']) ? $data['type'] : null;
    $id = isset($data['id']) ? intval($data['id']) : 0;
    $student_id = isset($data['studentid']) ? intval($data['studentid']) : 0;

    if (!$type || $id === 0 || $student_id === 0) {
        http_response_code(400); // Bad Request
        echo json_encode(['message' => 'Invalid or missing parameters']);
        exit;
    }

    try {
        if ($type === 'module') {
            // Insert into modules_students
            $stmt = $con->prepare('INSERT INTO modules_students (module_id, student_id, status) VALUES (?, ?, ?)');
            $stmt->execute([$id, $student_id, 0]);

        } elseif ($type === 'subject') {
            // Insert into studentssubjects
            $stmt = $con->prepare('INSERT INTO studentssubjects (subjectid, studentid, approve) VALUES (?, ?, ?)');
            $stmt->execute([$id, $student_id, 0]);

        } else {
            http_response_code(400); // Bad Request
            echo json_encode(['message' => 'Invalid type specified']);
            exit;
        }

        // Success response
        http_response_code(201); // Created
        echo json_encode(['message' => 'Data inserted successfully']);

    } catch (Exception $e) {
        http_response_code(500); // Internal Server Error
        echo json_encode(['message' => 'An error occurred', 'error' => $e->getMessage()]);
    }
} else {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>