<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

// Base path for file URLs
$baseFilePath = 'https://optima-software-solutions.com/falcon/dasboard/uploads/files/';

if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    // Get the contentid and type from the query parameters
    $contentId = isset($_GET['contentid']) ? intval($_GET['contentid']) : 0;
    $type = isset($_GET['type']) ? $_GET['type'] : '';

    if ($contentId == 0 || empty($type)) {
        http_response_code(400); // Bad Request
        echo json_encode(['message' => 'Invalid or missing contentid or type']);
        exit;
    }

    try {
        // Initialize the query variables
        $tableName = '';

        // Determine which table to query based on the content type
        switch (strtolower($type)) {
            case 'video':
            case 'videos':
                $tableName = 'videos';
                break;
            case 'quiz':
            case 'quizzes':
                $tableName = 'quizes';
                break;
            case 'assignment':
            case 'assignments':
                $tableName = 'homeworks';
                break;
            case 'material':
            case 'materials':
                $tableName = 'files';
                break;
            default:
                http_response_code(400); // Bad Request
                echo json_encode(['message' => 'Invalid content type']);
                exit;
        }

        // Prepare the SQL query to fetch the content by ID
        // Include iframe only for videos
        if ($tableName === 'videos') {
            $stmt = $con->prepare("SELECT id, name, chapterid, iframe FROM $tableName WHERE id = ?");
        } else if ($tableName === 'files') {
            // Fetch file with full path for materials
            $stmt = $con->prepare("SELECT id, name, chapterid, file FROM $tableName WHERE id = ?");
        } else {
            $stmt = $con->prepare("SELECT id, name, chapterid FROM $tableName WHERE id = ?");
        }

        $stmt->execute([$contentId]);
        $content = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($content) {
            // Cast id and chapterid to strings
            $content['id'] = (string) $content['id'];
            $content['chapterid'] = (string) $content['chapterid']; // Ensure chapterid is cast to string

            // Fetch the chapter name using the chapterid
            $stmt = $con->prepare('SELECT name FROM week_chapters WHERE id = ?');
            $stmt->execute([$content['chapterid']]);
            $chapter = $stmt->fetch(PDO::FETCH_ASSOC);

            // Attach chapter name to the content
            $content['chapter_name'] = $chapter['name'] ?? 'Unknown';

            // Append full file path for material (files)
            if ($tableName === 'files') {
                $content['file'] = $baseFilePath . $content['file'];
            }

            // Return the content if found
            echo json_encode(['type' => $type, 'content' => $content]);
        } else {
            // Return a 404 if the content is not found
            http_response_code(404); // Not Found
            echo json_encode(['message' => 'Content not found']);
        }

    } catch (Exception $e) {
        http_response_code(500); // Internal Server Error
        echo json_encode(['message' => 'An error occurred', 'error' => $e->getMessage()]);
    }
} else {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>
