<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    try {
        // Base URL for images
        $baseUrl = 'https://optima-software-solutions.com/falcon/dasboard/uploads/admins/'; // Base URL for doctor images

        // Fetch all doctors (admins) where the type is 'teacher'
        $stmt = $con->prepare('SELECT id, name, phone, description, image
            FROM admins
            WHERE type = ?');
        $stmt->execute(['teacher']);
        $doctors = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Add image URLs and cast id to string for each doctor
        foreach ($doctors as &$doctor) {
            // Construct the image URL
            $doctor['image_url'] = !empty($doctor['image']) ? $baseUrl . $doctor['image'] : 'No image found';
            // Cast the id to string
            $doctor['id'] = (string) $doctor['id'];
        }

        // Prepare the response with success message
        $response = [
            'message' => 'success',
            'doctors' => $doctors
        ];

    } catch (Exception $e) {
        // In case of an error, return a failure message
        $response = [
            'message' => 'failure',
            'error' => $e->getMessage()
        ];
        http_response_code(500); // Internal Server Error
    }

    echo json_encode($response);

} else {
    // Invalid request method, return an error response
    http_response_code(405);
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>
