<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    // Get the assignment ID from the URL parameters
    $assignmentId = isset($_GET['assignmentid']) ? intval($_GET['assignmentid']) : 0;

    if ($assignmentId <= 0) {
        http_response_code(400); // Bad Request
        echo json_encode(['message' => 'Invalid assignment ID']);
        exit;
    }

    try {
        // Fetch the homework and subject details
        $stmt = $con->prepare('SELECT e.id AS homework_id, e.name AS homework_name, s.name AS subject_name
            FROM homeworks e
            JOIN subjects s ON e.subjectid = s.id
            WHERE e.id = ?'
        );
        $stmt->execute([$assignmentId]);
        $homework = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$homework) {
            http_response_code(404); // Not Found
            echo json_encode(['message' => 'Homework not found']);
            exit;
        }

        // Cast homework_id to string
        $homework['homework_id'] = (string) $homework['homework_id'];

        // Fetch the questions related to the homework
        $stmt = $con->prepare('
            SELECT eq.questionid, q.question, q.choice1, q.choice2, q.choice3, q.choice4, q.answer
            FROM homeworkquestions eq
            JOIN questions q ON eq.questionid = q.id
            WHERE eq.homeworkid = ?'
        );
        $stmt->execute([$assignmentId]);
        $questions = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Prepare questions with options and cast questionid to string
        $formattedQuestions = [];
        foreach ($questions as $question) {
            $formattedQuestions[] = [
                'questionid' => (string) $question['questionid'], // Cast to string
                'question' => $question['question'],
                'options' => [
                    'choice1' => $question['choice1'],
                    'choice2' => $question['choice2'],
                    'choice3' => $question['choice3'],
                    'choice4' => $question['choice4']
                ]
            ];
        }

        // Prepare success response with subject name, homework name, and questions
        $response = [
            'subject_name' => $homework['subject_name'],
            'homework_name' => $homework['homework_name'],
            'homework_id' => $homework['homework_id'], // Include homework_id in the response
            'questions' => $formattedQuestions
        ];
        echo json_encode($response);

    } catch (Exception $e) {
        // In case of an error
        http_response_code(500); // Internal Server Error
        echo json_encode(['message' => 'Failed to retrieve questions', 'error' => $e->getMessage()]);
    }
} else {
    // Invalid request method
    http_response_code(405); // Method Not Allowed
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>
