<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    // Get the quiz ID from the URL parameters
    $quizId = isset($_GET['quizid']) ? intval($_GET['quizid']) : 0;

    if ($quizId <= 0) {
        http_response_code(400); // Bad Request
        echo json_encode(['message' => 'Invalid quiz ID']);
        exit;
    }

    try {
        // Fetch the exam and subject details
        $stmt = $con->prepare('
            SELECT e.id AS exam_id, e.name AS exam_name, s.name AS subject_name
            FROM exams e
            JOIN subjects s ON e.subjectid = s.id
            WHERE e.id = ?'
        );
        $stmt->execute([$quizId]);
        $exam = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$exam) {
            http_response_code(404); // Not Found
            echo json_encode(['message' => 'Exam not found']);
            exit;
        }

        // Cast exam_id to string
        $exam['exam_id'] = (string) $exam['exam_id'];

        // Fetch the questions related to the exam
        $stmt = $con->prepare('
            SELECT eq.questionid, q.question, q.choice1, q.choice2, q.choice3, q.choice4, q.answer
            FROM examquestions eq
            JOIN questions q ON eq.questionid = q.id
            WHERE eq.examid = ?'
        );
        $stmt->execute([$quizId]);
        $questions = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Prepare questions with options and cast questionid to string
        $formattedQuestions = [];
        foreach ($questions as $question) {
            $formattedQuestions[] = [
                'questionid' => (string) $question['questionid'], // Cast to string
                'question' => $question['question'],
                'options' => [
                    'choice1' => $question['choice1'],
                    'choice2' => $question['choice2'],
                    'choice3' => $question['choice3'],
                    'choice4' => $question['choice4']
                ]
            ];
        }

        // Prepare success response with subject name, exam name, and questions
        $response = [
            'subject_name' => $exam['subject_name'],
            'exam_name' => $exam['exam_name'],
            'exam_id' => $exam['exam_id'], // Include exam_id in the response
            'questions' => $formattedQuestions
        ];
        echo json_encode($response);

    } catch (Exception $e) {
        // In case of an error
        http_response_code(500); // Internal Server Error
        echo json_encode(['message' => 'Failed to retrieve questions', 'error' => $e->getMessage()]);
    }
} else {
    // Invalid request method
    http_response_code(405); // Method Not Allowed
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>
