<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    // Get the studentid from the URL parameters
    if (!isset($_GET['studentid'])) {
        http_response_code(400); // Bad Request
        echo json_encode(['message' => 'studentid is required']);
        exit;
    }

    $studentId = $_GET['studentid'];
    $baseUrl = 'https://optima-software-solutions.com/falcon/dasboard/uploads/'; // Base URL for images
    $baseUrlDoctors = 'https://optima-software-solutions.com/falcon/dasboard/uploads/doctors/'; // Base URL for doctor images

    try {
        // Fetch the modules for the student
        $stmt = $con->prepare('SELECT m.id AS module_id, m.name AS module_name, m.price AS module_price, m.description AS module_description, m.startdate AS module_startdate, m.enddate AS module_enddate, m.image
            FROM modules_students ms
            JOIN modules m ON ms.module_id = m.id
            WHERE ms.student_id = ?');
        $stmt->execute([$studentId]);
        $modules = $stmt->fetchAll(PDO::FETCH_ASSOC);

        $response = ['modules' => []];

        // Fetch subjects and chapters for each module
        foreach ($modules as &$module) {
            $module['module_id'] = (string) $module['module_id']; // Cast module_id to string
            $module['module_image_url'] = !empty($module['image']) ? $baseUrl . 'modules/' . $module['image'] : 'No image found';

            // Fetch the subjects for the module
            $stmt = $con->prepare('SELECT s.id AS subject_id, s.name AS subject_name, s.description AS subject_description, s.price AS subject_price, s.image AS subject_image
                FROM subjects s
                WHERE s.module = ?');
            $stmt->execute([$module['module_id']]); // Use the string casted module_id
            $subjects = $stmt->fetchAll(PDO::FETCH_ASSOC);

            // Fetch the chapters for each subject
            foreach ($subjects as &$subject) {
                $subject['subject_id'] = (string) $subject['subject_id']; // Cast subject_id to string
                $subject['subject_price'] = (string) $subject['subject_price']; // Cast subject_price to string
                $subject['subject_image_url'] = !empty($subject['subject_image']) ? $baseUrl . 'subjects/' . $subject['subject_image'] : 'No image found';

                $stmt = $con->prepare('SELECT wc.id AS chapter_id, wc.name AS chapter_name, wc.description AS chapter_description, wc.image AS chapter_image
                    FROM week_chapters wc
                    WHERE wc.subjectid = ?');
                $stmt->execute([$subject['subject_id']]); // Use the string casted subject_id
                $chapters = $stmt->fetchAll(PDO::FETCH_ASSOC);

                // Add image URLs to chapters
                foreach ($chapters as &$chapter) {
                    $chapter['chapter_id'] = (string) $chapter['id']; // Cast chapter_id to string
                    $chapter['chapter_image_url'] = !empty($chapter['chapter_image']) ? $baseUrl . 'chapters/' . $chapter['chapter_image'] : 'No image found';
                }

                // Add chapters to the subject
                $subject['chapters'] = $chapters;

                // Fetch the doctors for the subject
                $stmt = $con->prepare('SELECT sd.doctor_id, a.name AS doctor_name, a.phone AS doctor_phone, a.description AS doctor_description, a.image AS doctor_image
                    FROM subjects_doctors sd
                    JOIN admins a ON sd.doctor_id = a.id
                    WHERE sd.subject_id = ?');
                $stmt->execute([$subject['subject_id']]); // Use the string casted subject_id
                $doctors = $stmt->fetchAll(PDO::FETCH_ASSOC);

                // Add image URLs to doctors
                foreach ($doctors as &$doctor) {
                    $doctor['doctor_id'] = (string) $doctor['doctor_id']; // Cast doctor_id to string
                    $doctor['doctor_image_url'] = !empty($doctor['doctor_image']) ? $baseUrlDoctors . $doctor['doctor_image'] : 'No image found';
                }

                // Add doctors to the subject
                $subject['doctors'] = $doctors;
            }

            // Add subjects to the module
            $module['subjects'] = $subjects;

            // Add the module to the response
            $response['modules'][] = $module;
        }

        // Send the response
        echo json_encode($response);

    } catch (Exception $e) {
        http_response_code(500); // Internal Server Error
        echo json_encode(['message' => 'Failed to fetch data', 'error' => $e->getMessage()]);
    }

} else {
    // Invalid request method
    http_response_code(405); // Method Not Allowed
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>