<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    // Check if 'contentid' is provided in the query parameters
    if (!isset($_GET['contentid']) || empty($_GET['contentid'])) {
        http_response_code(400); // Bad Request
        echo json_encode(['message' => 'Content ID parameter is required']);
        exit;
    }

    $contentId = $_GET['contentid'];
    $baseFilePath = 'https://optima-software-solutions.com/falcon/dashboard/uploads/files/'; // Base file path

    try {
        // Fetch videos associated with the content ID
        $stmtVideos = $con->prepare('SELECT id, name, iframe FROM videos WHERE id = ?');
        $stmtVideos->execute([$contentId]);
        $videos = $stmtVideos->fetchAll(PDO::FETCH_ASSOC);

        // Fetch files associated with the content ID
        $stmtFiles = $con->prepare('SELECT id, name, file FROM files WHERE id = ?'); // Changed id to content_id
        $stmtFiles->execute([$contentId]);
        $files = $stmtFiles->fetchAll(PDO::FETCH_ASSOC);

        // Prepend the base file path to each file's path
        foreach ($files as &$file) {
            $file['file'] = $baseFilePath . $file['file'];
        }

        // Cast the id of each video and file to string
        foreach ($videos as &$video) {
            $video['id'] = (string) $video['id']; // Cast video id to string
        }
        foreach ($files as &$file) {
            $file['id'] = (string) $file['id']; // Cast file id to string
        }

        // Combine videos and files into a single array
        $response = [
            'videos' => $videos,
            'files' => $files,
        ];

        // Check if response contains any content
        if (empty($videos) && empty($files)) {
            // No content available
            http_response_code(404); // Not Found
            echo json_encode(['message' => 'No content available']);
        } else {
            // Success
            echo json_encode($response);
        }
    } catch (Exception $e) {
        // In case of an error, return a failure message
        http_response_code(500); // Internal Server Error
        $response = ['message' => 'Error retrieving content', 'error' => $e->getMessage()];
        echo json_encode($response);
    }
} else {
    // Invalid request method, return an error response
    http_response_code(405); // Method Not Allowed
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>
