<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    try {
        // Fetch all universities
        $stmt = $con->query('SELECT * FROM universities');
        $universitiesData = $stmt->fetchAll(PDO::FETCH_ASSOC);

        $universities = [];

        foreach ($universitiesData as $university) {
            $universityId = $university['id'];

            // Fetch colleges related to the current university
            $stmtColleges = $con->prepare('SELECT * FROM colleges WHERE university = ?');
            $stmtColleges->execute([$universityId]);
            $collegesData = $stmtColleges->fetchAll(PDO::FETCH_ASSOC);

            $colleges = [];

            foreach ($collegesData as $college) {
                $collegeId = $college['id'];

                // Fetch levels related to the current college
                $stmtLevels = $con->prepare('SELECT * FROM levels WHERE college = ?');
                $stmtLevels->execute([$collegeId]);
                $levelsData = $stmtLevels->fetchAll(PDO::FETCH_ASSOC);

                $levels = [];
                foreach ($levelsData as $level) {
                    $levels[] = [
                        'id' => (string) $level['id'],
                        'name' => $level['name']
                    ];
                }

                $colleges[] = [
                    'id' => (string) $college['id'],
                    'name' => $college['name'],
                    'levels' => $levels
                ];
            }

            $universities[] = [
                'id' => (string) $university['id'],
                'name' => $university['name'],
                'colleges' => $colleges
            ];
        }

        // Prepare the response with success message
        $response = [
            'message' => 'success',
            'universities' => $universities
        ];

    } catch (Exception $e) {
        // In case of an error, return a failure message
        $response = [
            'message' => 'failure',
            'error' => $e->getMessage()
        ];
        http_response_code(500); // Internal Server Error
    }

    echo json_encode($response);

} else {
    // Invalid request method, return an error response
    http_response_code(405);
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>
