<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'GET') {
    // Check if 'studentid' is provided in the query parameters
    if (!isset($_GET['studentid']) || empty($_GET['studentid'])) {
        http_response_code(400); // Bad Request
        echo json_encode(['message' => 'Student ID parameter is missing or empty']);
        exit;
    }

    $studentId = $_GET['studentid'];

    try {
        // Fetch student details
        $stmt = $con->prepare('SELECT id, username, email FROM students WHERE id = ?');
        $stmt->execute([$studentId]);
        $student = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$student) {
            http_response_code(404); // Not Found
            echo json_encode(['message' => 'Student not found']);
            exit;
        }

        // Cast the student ID to a string
        $student['id'] = (string) $student['id'];

        // Fetch the total money from the student_wallet table
        $stmt = $con->prepare('SELECT SUM(money) AS total_money FROM student_wallet WHERE studentid = ?');
        $stmt->execute([$studentId]);
        $wallet = $stmt->fetch(PDO::FETCH_ASSOC);
        $totalMoney = (int) ($wallet['total_money'] ?? 0); // Cast to integer

        // Prepare the response
        $response = [
            'message' => 'success',
            'student' => $student,
            'total_money' => $totalMoney
        ];

    } catch (Exception $e) {
        // In case of an error, return a failure message
        $response = [
            'message' => 'failure',
            'error' => $e->getMessage()
        ];
        http_response_code(500); // Internal Server Error
    }

    echo json_encode($response);
} else {
    // Invalid request method
    http_response_code(405); // Method Not Allowed
    echo json_encode(['message' => 'Method Not Allowed']);
}
?>
