<?php
require_once 'connect.php'; // Include the database connection

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get the input data from the body
    $data = json_decode(file_get_contents('php://input'), true);

    // Validate input
    if (empty($data['studentid']) || empty($data['code'])) {
        http_response_code(400); // Bad Request
        echo json_encode(['error' => 'studentid and code are required']);
        exit;
    }

    $studentId = $data['studentid'];
    $code = $data['code'];

    try {
        // Check if the code exists for the given student in the codes table
        $stmt = $con->prepare('SELECT id, price, type FROM codes WHERE code = ? AND studentid = ?');
        $stmt->execute([$code, $studentId]);
        $codeData = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$codeData) {
            // If the code does not exist for the student, return an error
            http_response_code(400); // Bad Request
            echo json_encode(['error' => 'Code not valid']);
            exit;
        }

        // Insert the transaction into the student_wallet table
        $stmt = $con->prepare('INSERT INTO student_wallet (studentid, product_id, type, money, date, comment)
                            VALUES (?, ?, ?, ?, NOW(), ?)');
        $stmt->execute([
            $studentId,
            $codeData['id'],  // Using the code's ID as product_id
            $codeData['type'], // Type from the code
            $codeData['price'], // Money from the code
            'Wallet charge by code' // Comment
        ]);

        // Calculate the new balance (assuming you have a balance column in the student_wallet or a similar table)
        // Here we assume you would sum up all transactions for the student to get the new balance
        $stmt = $con->prepare('SELECT SUM(money) AS balance FROM student_wallet WHERE studentid = ?');
        $stmt->execute([$studentId]);
        $balance = $stmt->fetch(PDO::FETCH_ASSOC)['balance'];

        // Prepare and return the success response with the new balance
        $response = [
            'success' => 'wallet successfully charged',
            'new_balance' => $balance
        ];
        echo json_encode($response);
    } catch (Exception $e) {
        // Handle any errors
        http_response_code(500); // Internal Server Error
        echo json_encode(['error' => 'Error processing the request', 'details' => $e->getMessage()]);
    }
} else {
    // Invalid request method
    http_response_code(405);
    echo json_encode(['message' => 'Method Not Allowed']);
}
